@@ -3,6 +3,11 @@ import MySQLdb
 import _mysql
 import classes
 import sys
+
+if not sys.modules.has_key('gtk'):
+    import pygtk
+    pygtk.require('1.2')
+
 import gtk
 
 thedb="test"
